@@ -1,6 +1,6 @@
 `.onLoad` <- function(lib,pkg) {
-  cat("IBrokers version 0.9-1:\n")
-  cat("Implementing API Version 9.64\n\n")
+  message("IBrokers version 0.9-2:")
+  message("Implementing API Version 9.64")
   cat("This software comes with NO WARRANTY.  Not intended for production use!\n")
-  cat("See ?IBrokers for details\n")
+  message("See ?IBrokers for details")
 }
